@@ -79,7 +79,9 @@ Attributes:
 # Imported modules
 ########################################################################
 
-import getopt
+# Note: getopt is "soft deprecated" only and is safe to use; see: https://github.com/python/cpython/pull/105735
+
+import getopt  # pylint: disable=deprecated-module:
 import logging
 import os
 import sys
