@@ -70,11 +70,11 @@ Attributes:
 # Imported modules
 ########################################################################
 
-import collections
 import logging
 import math
 import os
 import platform
+import posixpath
 import re
 import sys
 import time
@@ -313,7 +313,7 @@ class AbsolutePathList(UnorderedList):
         Raises:
            ValueError: If item is not an absolute path
         """
-        if not os.path.isabs(item):
+        if not (os.path.isabs(item) or posixpath.isabs(item)):  # Python 3.13 does not treat / as absolute on Windows
             raise ValueError("Not an absolute path: [%s]" % item)
         list.append(self, encodePath(item))
 
@@ -323,7 +323,7 @@ class AbsolutePathList(UnorderedList):
         Raises:
            ValueError: If item is not an absolute path
         """
-        if not os.path.isabs(item):
+        if not (os.path.isabs(item) or posixpath.isabs(item)):  # Python 3.13 does not treat / as absolute on Windows
             raise ValueError("Not an absolute path: [%s]" % item)
         list.insert(self, index, encodePath(item))
 
@@ -334,7 +334,7 @@ class AbsolutePathList(UnorderedList):
            ValueError: If any item is not an absolute path
         """
         for item in seq:
-            if not os.path.isabs(item):
+            if not (os.path.isabs(item) or posixpath.isabs(item)):  # Python 3.13 does not treat / as absolute on Windows
                 raise ValueError("Not an absolute path: [%s]" % item)
         for item in seq:
             list.append(self, encodePath(item))
@@ -1331,7 +1331,7 @@ def getFunctionReference(module, function):
     obj = module
     for part in parts:
         obj = getattr(obj, part)
-    if not isinstance(obj, collections.abc.Callable):
+    if not callable(obj):
         raise ValueError("Reference to %s.%s is not callable." % (module, function))
     return obj
 
@@ -2019,7 +2019,8 @@ def dereferenceLink(path, absolute=True):
     """
     if os.path.islink(path):
         result = os.readlink(path)
-        if absolute and not os.path.isabs(result):
+        # Python 3.13+ does not treat / as absolute on Windows
+        if absolute and not (os.path.isabs(result) or posixpath.isabs(result)):
             result = os.path.abspath(os.path.join(os.path.dirname(path), result))
         return result
     return path
